# API Reference

This page provides an auto-generated summary of xWRF’s API.

For more details and examples, refer to the relevant chapters in the main part of the documentation.

## Top-level API

```{eval-rst}
.. currentmodule:: xwrf

.. autosummary::
   :toctree: generated/

```

## Dataset

### Attributes

```{eval-rst}
.. currentmodule:: xarray

.. autosummary::
   :toctree: generated/
   :template: autosummary/accessor_attribute.rst

```

### Methods

```{eval-rst}
.. currentmodule:: xarray

.. autosummary::
   :toctree: generated/
   :template: autosummary/accessor_method.rst

   Dataset.xwrf.postprocess
```

## DataArray

### Attributes

```{eval-rst}
.. currentmodule:: xarray

.. autosummary::
   :toctree: generated/
   :template: autosummary/accessor_attribute.rst

```

### Methods

```{eval-rst}
.. currentmodule:: xarray

.. autosummary::
   :toctree: generated/
   :template: autosummary/accessor_method.rst

```

## Configuration

```{eval-rst}
.. currentmodule:: xwrf

.. autosummary::
   :toctree: generated/

   config.Config

```

## Sample Datasets

```{eval-rst}
.. currentmodule:: xwrf

.. autosummary::
   :toctree: generated/

   tutorial.open_dataset
```
